@@ -17,7 +17,10 @@
     }
     if (!is.null(value)) {
         if (!is.character(value)) {
-            stop("Argument \'value\' must be of class \"character\"")
+            if (check_numeric(value)) {
+                value <- as.character(value)
+            } else
+                stop("Argument \'value\' must be of class \"character\"")
         }
         req_body$value <- jsonlite::unbox(value)
     } else {
@@ -53,7 +56,10 @@
     }
     if (!is.null(value)) {
         if (!is.character(value)) {
-            stop("Argument \'value\' must be of class \"character\"")
+            if (check_numeric(value)) {
+                value <- as.character(value)
+            } else
+                stop("Argument \'value\' must be of class \"character\"")
         }
         req_body$value <- jsonlite::unbox(value)
     } else {
@@ -83,7 +89,10 @@
     if (is.null(study_id)) {
         stop("Must supply a \'study_id\' argument")
     } else if (!is.character(study_id)) {
-        stop("Argument \'study_id\' must be of class \"character\"")
+        if (check_numeric(study_id)) {
+            study_id <- as.character(study_id)
+        } else
+            stop("Argument \'study_id\' must be of class \"character\"")
     }
     format <- match.arg(format)
     res <- otl_GET(path=paste("study",
@@ -124,7 +133,9 @@
 
 ##' @importFrom httr content
 .get_study_subtree <- function(study_id, tree_id, subtree_id,
-                               format=c("newick", "nexus", "nexml", "json"), ...) {
+                               format=c("newick", "nexus", "nexml"),
+                               tip_label = c("ot:originallabel", "ot:ottid", "ot:otttaxonname"),
+                               ...) {
     if (is.null(study_id)) {
         stop("Must supply a \'study_id\' argument")
     } else if (!is.character(study_id)) {
@@ -142,8 +153,9 @@
     }
     format <- match.arg(format)
     format <- otl_formats(format)
-    url_stem <- paste("study", study_id, "tree", paste0(tree_id, format), sep="/")
-    res <- otl_GET(path=paste(url_stem, "?subtree_id=", subtree_id, sep=""), ...)
+    tip_label <- match.arg(tip_label)
+    url_stem <- paste("study", study_id, "subtree", paste0(tree_id, format), sep="/")
+    res <- otl_GET(path=paste0(url_stem, "?subtree_id=", subtree_id, "&tip_label=", tip_label), ...)
     res
 }
 
