@@ -12,21 +12,22 @@ taxon_search <- tnrs_match_names(names=mu$species, context_name="All life")
 knitr::kable(taxon_search)
 
 ## ---- munge--------------------------------------------------------------
-mu$ott_name <- taxon_search$unique_name
+mu$ott_name <- unique_name(taxon_search)
 mu$ott_id <- taxon_search$ott_id
 
 ## ---- properties---------------------------------------------------------
 studies_properties()
 
 ## ----taxon_count---------------------------------------------------------
-studies_find_trees(property="ot:ottId", value="180195")
+studies_find_trees(property="ot:ottId", value=as.character(ott_id(taxon_search)[1]))
 
 ## ---- all_taxa_count-----------------------------------------------------
 hits <- lapply(mu$ott_id, studies_find_trees, property="ot:ottId", detailed = FALSE)
 sapply(hits, function(x) sum(x[["n_matched_trees"]]))
 
 ## ----subtree,  fig.width=7, fig.height=4---------------------------------
-tr <- tol_induced_subtree(ott_ids=mu$ott_id)
+ott_in_tree <- ott_id(taxon_search)[is_in_tree(ott_id(taxon_search))]
+tr <- tol_induced_subtree(ott_ids = ott_in_tree)
 plot(tr)
 
 ## ---- match_names--------------------------------------------------------
@@ -34,8 +35,7 @@ mu$ott_name[1]
 tr$tip.label[4]
 
 ## ---- sub----------------------------------------------------------------
-tr$tip.label <- sub("_ott\\d+", "", tr$tip.label)
-tr$tip.label <- sub("_", " ", tr$tip.label)
+tr$tip.label <- strip_ott_ids(tr$tip.label, remove_underscores=TRUE)
 tr$tip.label %in% mu$ott_name
 
 ## ----phylobase-----------------------------------------------------------
@@ -47,3 +47,16 @@ tree_data <- phylo4d(tr, mu_numeric)
 ## ----  fig.width=7, fig.height=5-----------------------------------------
 plot(tree_data)
 
+## ------------------------------------------------------------------------
+extra_data <- study_external_IDs("pg_1980")
+extra_data
+
+## ------------------------------------------------------------------------
+library(rentrez)
+seqs <- entrez_fetch(db="nucleotide", id=extra_data$nucleotide_ids[1:2], rettype="fasta")
+cat(seqs)
+
+## ------------------------------------------------------------------------
+Tt_ids <- taxon_external_IDs(mu$ott_id[2])
+Tt_ids
+
